package
Version:
v0.1.5
Opens a new window with list of versions in this module.
Published: Nov 24, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CDPClient struct {
}
CDPClient
TODO: to implement fetcher using ChromeDP
Source Files
¶
Click to show internal directories.
Click to hide internal directories.